@@ -172,11 +172,12 @@ resample_img <- function(source, target, interp = 3L) {
 
 #' Plot a volume as an image overlay.
 #' @export
-#' @param voi volume data as a nifti object or path to data file.
 #' @param mri image data as a nifti object or path to data file.
-#' @param flip_lr flip the image in the left-right direction.
+#' @param voi volume data as a nifti object or path to data file.
 #' @param export_path optional path to save the image in png format.
-plot_voi_overlay <- function(voi, mri, flip_lr = FALSE, export_path = NULL) {
+#' @param zlim underlay intensity limits.
+#' @param ... additional arguments to the ortho3 function.
+plot_voi_overlay <- function(mri, voi, export_path = NULL, zlim = NULL, ...) {
   
   if ("character" %in% class(mri)) mri <- RNifti::readNifti(mri)
   
@@ -190,32 +191,24 @@ plot_voi_overlay <- function(voi, mri, flip_lr = FALSE, export_path = NULL) {
   # check the image orientation etc is the same
   check_geom(voi, mri)
  
-  # swap L/R direction 
-  if (flip_lr) {
-    voi <- nifti_flip_lr(voi)
-    mri <- nifti_flip_lr(mri)
-  }
-  
   # get the centre of gravity coords
-  vox_inds <- get_voi_cog(voi)
   plot_col <- grDevices::heat.colors(10)
   
-  zlim <- stats::quantile(mri, probs = c(0, 0.999))
+  if (is.null(zlim)) zlim <- stats::quantile(mri, probs = c(0, 0.999))
   
   if (!is.null(export_path)) grDevices::png(export_path)
-  ortho3(mri, voi, xyz = vox_inds, col_ol = plot_col, zlim = zlim,
-         zlim_ol = c(0.99, 2), alpha = 0.4, colourbar = FALSE)
+  ortho3(mri, voi, col_ol = plot_col, zlim = zlim, zlim_ol = c(0.99, 2),
+         alpha = 0.4, colourbar = FALSE, ...)
   if (!is.null(export_path)) grDevices::dev.off()
 }
 
 #' Plot a volume as an overlay on a segmented brain volume.
-#' @param voi volume data as a nifti object.
 #' @param mri_seg segmented brain volume as a nifti object.
-#' @param flip_lr flip the image in the left-right direction.
+#' @param voi volume data as a nifti object.
 #' @param export_path optional path to save the image in png format.
+#' @param ... additional arguments to the ortho3 function.
 #' @export
-plot_voi_overlay_seg <- function(voi, mri_seg, flip_lr = FALSE,
-                                 export_path = NULL) {
+plot_voi_overlay_seg <- function(mri_seg, voi, export_path = NULL, ...) {
   
   if ("character" %in% class(mri_seg)) mri_seg <- RNifti::readNifti(mri_seg)
   
@@ -229,15 +222,6 @@ plot_voi_overlay_seg <- function(voi, mri_seg, flip_lr = FALSE,
   # check the image orientation etc is the same
   check_geom(voi, mri_seg)
   
-  # swap L/R direction 
-  if (flip_lr) {
-    voi     <- nifti_flip_lr(voi)
-    mri_seg <- nifti_flip_lr(mri_seg)
-  }
-  
-  # get the centre of gravity coords
-  vox_inds <- get_voi_cog(voi)
-  
   pvs <- get_voi_seg(voi, mri_seg)
   table <- paste("WM\t\t=  ", sprintf("%.1f", pvs[["WM"]]), "%\nGM\t\t=  ", 
                  sprintf("%.1f", pvs[["GM"]]), "%\nCSF\t=  ", 
@@ -247,9 +231,9 @@ plot_voi_overlay_seg <- function(voi, mri_seg, flip_lr = FALSE,
   plot_col <- add_alpha(grDevices::heat.colors(10), 0.4)
   
   if (!is.null(export_path)) grDevices::png(export_path)
- 
-  ortho3(mri_seg, voi, xyz = vox_inds, col_ol = plot_col,
-         zlim_ol = c(0.99, 2), alpha = 0.4, colourbar = FALSE)
+  
+  ortho3(mri_seg, voi, col_ol = plot_col, zlim_ol = c(0.99, 2), alpha = 0.4,
+         colourbar = FALSE, zlim = range(mri_seg), ...)
   
   graphics::par(xpd = NA)
   graphics::text(x = 0.55, y = 0.22, labels = c(table), col = "white", pos = 4, 
