@@ -24,9 +24,9 @@ read_lcm_raw <- function(fname, ft, fs, ref) {
 
   nuc <- def_nuc()
   
-  mrs_data <- mrs_data(data = data, ft = ft, resolution = res, te = NULL,
-                       ref = ref, nuc = nuc, freq_domain = freq_domain,
-                       affine = NULL, meta = NULL)
+  mrs_data <- mrs_data(data = data, ft = ft, resolution = res, ref = ref,
+                       nuc = nuc, freq_domain = freq_domain, affine = NULL,
+                       meta = NULL)
   
   return(mrs_data)
 }
\ No newline at end of file
