@@ -74,9 +74,9 @@ read_list_data <- function(fname, ft, fs, ref) {
     dim(ref_data) <- c(N, chans, ref_N/chans, 1, 1, 1, 1)
     ref_data <- aperm(ref_data, c(7,6,5,4,3,2,1))
     
-    ref_mrs <- mrs_data(data = ref_data, ft = ft, resolution = res, te = NULL,
-                        ref = ref, nuc = nuc, freq_domain = freq_domain,
-                        affine = NULL, meta = NULL)
+    ref_mrs <- mrs_data(data = ref_data, ft = ft, resolution = res, ref = ref,
+                        nuc = nuc, freq_domain = freq_domain, affine = NULL,
+                        meta = NULL)
   }
   
   metab_data <- cplx_vec[metab_start:metab_end]
@@ -87,13 +87,13 @@ read_list_data <- function(fname, ft, fs, ref) {
   dim(noise_data) <- c(N, chans, noise_N/chans, 1, 1, 1, 1)
   noise_data <- aperm(noise_data, c(7,6,5,4,3,2,1))
   
-  metab_mrs <- mrs_data(data = metab_data, ft = ft, resolution = res, te = NULL,
-                        ref = ref, nuc = nuc, freq_domain = freq_domain,
-                        affine = NULL, meta = NULL)
+  metab_mrs <- mrs_data(data = metab_data, ft = ft, resolution = res, ref = ref,
+                        nuc = nuc, freq_domain = freq_domain, affine = NULL,
+                        meta = NULL)
   
-  noise_mrs <- mrs_data(data = noise_data, ft = ft, resolution = res, te = NULL,
-                        ref = ref, nuc = nuc, freq_domain = freq_domain,
-                        affine = NULL, meta = NULL)
+  noise_mrs <- mrs_data(data = noise_data, ft = ft, resolution = res, ref = ref,
+                        nuc = nuc, freq_domain = freq_domain, affine = NULL,
+                        meta = NULL)
   
   list(metab = metab_mrs, ref = ref_mrs, noise = noise_mrs)
 }
\ No newline at end of file
