@@ -65,9 +65,11 @@ read_pfile <- function(fname, n_ref_scans = NULL) {
   ref <- def_ref()
   nuc <- def_nuc()
   
+  meta <- list(EchoTime = hdr$te)
+  
   mrs_data <- mrs_data(data = data, ft = hdr$ps_mps_freq / 10, resolution = res,
-                       te = hdr$te, ref = ref, nuc = nuc,
-                       freq_domain = freq_domain, affine = NULL, meta = NULL)
+                       ref = ref, nuc = nuc, freq_domain = freq_domain,
+                       affine = NULL, meta = meta)
   
   if (hdr$rhuser19 > 0) {
     # split water and metab data for each echo
